<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he_IL">
<context>
    <name>AppOptionsDialog</name>
    <message>
        <source>App Options</source>
        <translation>אפשרויות היישום</translation>
    </message>
    <message>
        <source>Play sound when finished</source>
        <translation>להשמיע צליל עם הסיום</translation>
    </message>
    <message>
        <source>Eject media when finished</source>
        <translation>לשלוף את אמצעי האחסון עם סיום הפעולה</translation>
    </message>
    <message>
        <source>Enable anonymous statistics (telemetry)</source>
        <translation>הפעלת סטטיסטיקה אלמונית (מדדים)</translation>
    </message>
    <message>
        <source>What is this?</source>
        <translation>מה זה?</translation>
    </message>
    <message>
        <source>Disable warnings</source>
        <translation>השבתת אזהרות</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <source>Disable warnings?</source>
        <translation>להשבית אזהרות?</translation>
    </message>
    <message>
        <source>If you disable warnings, Raspberry Pi Imager will &lt;b&gt;not show confirmation prompts before writing images&lt;/b&gt;. You will still be required to &lt;b&gt;type the exact name&lt;/b&gt; when selecting a system drive.</source>
        <translation>השבתת אזהרות תוביל לכך שצורב הדמויות של Raspberry Pi &lt;b&gt;לא יציג בקשות אישור לפני צריבת דמויות&lt;/b&gt;. עדיין יהיה עליך &lt;b&gt;להקליד את השם במדויק&lt;/b&gt; בעת בחירה בכונן מערכת.</translation>
    </message>
    <message>
        <source>Content Repository</source>
        <translation>מאגר תוכן</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <source>Close the options dialog without saving any changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save the selected options and apply them to Raspberry Pi Imager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep warnings enabled and return to the options dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable confirmation prompts before writing images, requiring only exact name entry for system drives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play an audio notification when the image write process completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically eject the storage device when the write process completes successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send anonymous usage statistics to help improve Raspberry Pi Imager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip confirmation dialogs before writing images (advanced users only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change the source of operating system images between official Raspberry Pi repository and custom sources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Secure Boot RSA Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select RSA Private Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PEM Files (*.pem);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PEM Files (*.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AsyncCacheWriter</name>
    <message>
        <source>Cache write error: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonStrings</name>
    <message>
        <source>Only proceed if you fully understand the risks.</source>
        <translation>להמשיך רק אם הסיכונים ברורים לך לחלוטין.</translation>
    </message>
    <message>
        <source>Selecting the wrong drive will permanently erase data and can render your computer inoperable.</source>
        <translation>בחירה בכונן השגוי תמחק את כל הנתונים לצמיתות ואולי אף תפגע ביכולת של המחשב שלך להעלות את מערכת ההפעלה.</translation>
    </message>
    <message>
        <source>System drives typically contain files essential to the operation of your computer, and may include your personal files (photos, videos, documents).</source>
        <translation>כונני המערכת בדרך כלל מכילים קבצים חיוניים לפעולת המחשב שלך ועשויים גם להכיל את הקבצים האישיים שלך (תמונות, סרטונים, מסמכים).</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
    <message>
        <source>Image files (%1)</source>
        <translation>קובצי דמויות (%1)</translation>
    </message>
    <message>
        <source>Imager Repository Files (*.json)</source>
        <translation>קובצי מאגר של צורב הדמויות (‎*.json)</translation>
    </message>
    <message>
        <source>Public Key files (*.pub)</source>
        <translation>קובצי מפתח ציבורי (‎*.pub)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>No</source>
        <translation>לא</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>עיון</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>המשך</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>סיום</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>נא לבחור דמות</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמה:</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>התקן:</translation>
    </message>
    <message>
        <source>Storage:</source>
        <translation>אחסון:</translation>
    </message>
    <message>
        <source>No device selected</source>
        <translation>לא נבחר התקן</translation>
    </message>
    <message>
        <source>No image selected</source>
        <translation>לא נבחרה דמות</translation>
    </message>
    <message>
        <source>No storage selected</source>
        <translation>לא נבחר אחסון</translation>
    </message>
    <message>
        <source>Hostname configured</source>
        <translation>שם המארח הוגדר</translation>
    </message>
    <message>
        <source>User account configured</source>
        <translation>חשבון המשתמש הוגדר</translation>
    </message>
    <message>
        <source>SSH enabled</source>
        <translation>SSH הופעל</translation>
    </message>
    <message>
        <source>Wi‑Fi configured</source>
        <translation>הרשת האלחוטית הוגדרה</translation>
    </message>
    <message>
        <source>Raspberry Pi Connect enabled</source>
        <translation>Raspberry Pi Connect הופעל</translation>
    </message>
    <message>
        <source>I2C enabled</source>
        <translation>I2C הופעל</translation>
    </message>
    <message>
        <source>SPI enabled</source>
        <translation>SPI הופעל</translation>
    </message>
    <message>
        <source>USB Gadget mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1-Wire enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Localisation configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authorized keys files (authorized_keys)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmSystemDriveDialog</name>
    <message>
        <source>Size: %1</source>
        <translation>גודל: %1</translation>
    </message>
    <message>
        <source>Mounted as: %1</source>
        <translation>מעוגן בתור: %1</translation>
    </message>
    <message>
        <source>Not mounted</source>
        <translation>לא מעוגן</translation>
    </message>
    <message>
        <source>To continue, type the exact drive name below:</source>
        <translation>כדי להמשיך נא להקליד את שם הכונן במדויק להלן:</translation>
    </message>
    <message>
        <source>Type drive name exactly as shown above</source>
        <translation>נא להקליד את שם הכונן בדיוק כמו שמופיע לעיל</translation>
    </message>
    <message>
        <source>CANCEL</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>CONTINUE</source>
        <translation>המשך</translation>
    </message>
    <message>
        <source>Cancel operation and return to storage selection to choose a different device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed to write the image to this system drive after confirming the drive name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drive information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drive name to type: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drive name input. Type exactly: %1. %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmUnfilterDialog</name>
    <message>
        <source>By disabling system drive filtering, &lt;b&gt;system drives will be shown&lt;/b&gt; in the list.</source>
        <translation>השבתת סינון כונני מערכת תרגום ל&lt;b&gt;הצגת כונני המערכת&lt;/b&gt; ברשימה.</translation>
    </message>
    <message>
        <source>KEEP FILTER ON</source>
        <translation>להשאיר את המסנן פעיל</translation>
    </message>
    <message>
        <source>SHOW SYSTEM DRIVES</source>
        <translation>להציג כונני מערכת</translation>
    </message>
    <message>
        <source>Keep system drives hidden to prevent accidental damage to your operating system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove the safety filter and display system drives in the storage device list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceSelectionStep</name>
    <message>
        <source>Select your Raspberry Pi device</source>
        <translation>נא לבחור את התקן ה־Raspberry Pi שלך</translation>
    </message>
    <message>
        <source>Device selection list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DoneStep</name>
    <message>
        <source>Your choices:</source>
        <translation>הבחירות שלך:</translation>
    </message>
    <message>
        <source>The storage device was ejected automatically. You can now remove it safely.</source>
        <translation>התקן האחסון נשלף אוטומטית. כעת ניתן להסיר אותו בבטחה.</translation>
    </message>
    <message>
        <source>Please eject the storage device before removing it from your computer.</source>
        <translation>נא לשלוף את התקן האחסון בטרם הסרתו מהמחשב שלך.</translation>
    </message>
    <message>
        <source>Write Another</source>
        <translation>לצרוב אחד נוסף</translation>
    </message>
    <message>
        <source>Write complete!</source>
        <translation>הצריבה הושלמה!</translation>
    </message>
    <message>
        <source>Customisations applied:</source>
        <translation>ההתאמות חלו:</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>הפעלה מחדש</translation>
    </message>
    <message>
        <source>Operating system:</source>
        <translation>מערכת הפעלה:</translation>
    </message>
    <message>
        <source>Storage:</source>
        <translation>אחסון:</translation>
    </message>
    <message>
        <source>Reboot the system to apply changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Raspberry Pi Imager and exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to storage selection to write the same image to another storage device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>customization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>customizations</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadExtractThread</name>
    <message>
        <source>Error extracting archive: %1</source>
        <translation>שגיאה בחילוץ ארכיון: %1</translation>
    </message>
    <message>
        <source>Error mounting FAT32 partition</source>
        <translation>שגיאה בעיגון מחיצת FAT32</translation>
    </message>
    <message>
        <source>Operating system did not mount FAT32 partition</source>
        <translation>מערכת ההפעלה לא עיגנה מחיצת FAT32</translation>
    </message>
    <message>
        <source>Error changing to directory &apos;%1&apos;</source>
        <translation>שגיאה במעבר לתיקייה ‚%1’</translation>
    </message>
    <message>
        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
        <translation>שגיאת קריאה מאחסון.&lt;br&gt;כנראה שכרטיס ה־SD פגום.</translation>
    </message>
    <message>
        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
        <translation>וידוא הצריבה נכשל. תוכן כרטיס ה־SD שונה ממה שלכאורה נצרב אליו.</translation>
    </message>
</context>
<context>
    <name>DownloadThread</name>
    <message>
        <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
        <translation>נא לוודא ש־‚Raspberry Pi Imager (צורב קובצי דמות)’ מורשה לגשת ל‚כרכים נתיקים&apos; בהגדרות הפרטיות (תחת ‚קבצים ותיקיות’ או לחלופין להעניק לו ‚גישה מלאה לכוננים’).</translation>
    </message>
    <message>
        <source>Cannot open storage device &apos;%1&apos;.</source>
        <translation>לא ניתן לפתוח את התקן האחסון ‚%1’.</translation>
    </message>
    <message>
        <source>Write error while zero&apos;ing out MBR</source>
        <translation>שגיאת כתיבה במהלך כתיבת אפסים ל־MBR (רשומת טעינה עיקרית)</translation>
    </message>
    <message>
        <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
        <translation>שגיאת צריבה במהלך הניסיון למלא את החלק הסופי של הכרטיס באפסים.&lt;br&gt;יכול להיות שהכרטיס מפרסם על עצמו נפח שגוי (כנראה זיוף).</translation>
    </message>
    <message>
        <source>Error downloading: %1</source>
        <translation>שגיאת הורדה: %1</translation>
    </message>
    <message>
        <source>Access denied error while writing file to disk.</source>
        <translation>הגישה נדחתה תוך כדי הצריבה לכונן.</translation>
    </message>
    <message>
        <source>Error writing to storage (while flushing)</source>
        <translation>שגיאת צריבה לאחסון (במהלך מחיקה מוחלטת)</translation>
    </message>
    <message>
        <source>Error writing to storage (while fsync)</source>
        <translation>שגיאת צריבה לאחסון (במהלך fsync)</translation>
    </message>
    <message>
        <source>Error writing first block (partition table)</source>
        <translation>שגיאה בכתיבה לבלוק הראשון (טבלת מחיצות)</translation>
    </message>
    <message>
        <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
        <translation>שגיאת קריאה מאחסון.&lt;br&gt;כנראה שכרטיס ה־SD פגום.</translation>
    </message>
    <message>
        <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
        <translation>וידוא הצריבה נכשל. תוכן כרטיס ה־SD שונה ממה שלכאורה נצרב אליו.</translation>
    </message>
    <message>
        <source>Cached file is corrupt. SHA256 hash does not match expected value.&lt;br&gt;The cache file will be removed and the download will restart.</source>
        <translation>הקובץ שבמטמון פגום. גיבוב ה־SHA256 לא תואם לערך שאמור להיות.&lt;br&gt;קובץ המטמון יוסר וההורדה תתחיל מחדש.</translation>
    </message>
    <message>
        <source>Local file is corrupt or has incorrect SHA256 hash.&lt;br&gt;Expected: %1&lt;br&gt;Actual: %2</source>
        <translation>הקובץ המקומי פגום או שגיבוב ה־SHA256 שלו שגוי.&lt;br&gt;אמור להיות: %1&lt;br&gt;בפועל: %2</translation>
    </message>
    <message>
        <source>Download appears to be corrupt. SHA256 hash does not match.&lt;br&gt;Expected: %1&lt;br&gt;Actual: %2&lt;br&gt;Please check your network connection and try again.</source>
        <translation>נראה שההורדה פגומה. גיבוב ה־SHA256 לא תואם.&lt;br&gt;אמור להיות: %1&lt;br&gt;בפועל: %2&lt;br&gt;נא לבדוק האם החיבור שלך לרשת תקין ולנסות שוב.</translation>
    </message>
    <message>
        <source>Controlled Folder Access seems to be enabled. Please add rpi-imager.exe to the list of allowed apps and try again.</source>
        <translation>נראה שגישה מבוקרת לתיקיות פעילה. נא להוסיף את rpi-imager.exe לרשימת היישומים המורשים ולנסות שוב.</translation>
    </message>
    <message>
        <source>Error: Multiple partitions found on disk. Please ensure the disk is completely clean.</source>
        <translation>שגיאה: נמצאו מגוון מחיצות בכונן. נא לוודא שהכונן נקי לחלוטין.</translation>
    </message>
    <message>
        <source>The disk may be write-protected or in use by another application. Please ensure the disk is not mounted and try again.</source>
        <translation>נראה שהכונן מוגן מפני כתיבה או שיישום אחר משתמש בו. נא לוודא שהכונן אינו מעוגן ואז לנסות שוב.</translation>
    </message>
    <message>
        <source>Disk is full. Please use a larger storage device.</source>
        <translation>הכונן מלא. נא להשתמש בהתקן אחסון גדול יותר.</translation>
    </message>
    <message>
        <source>The disk is write-protected. Please check if the disk has a physical write-protect switch or is read-only.</source>
        <translation>התקן האחסון מוגן מפני כתיבה. נא לבדוק אם להתקן האחסון יש מתג הגנת כתיבה פיזי או שהוא לקריאה בלבד.</translation>
    </message>
    <message>
        <source>Media error detected. The storage device may be damaged or counterfeit. Please try a different device.</source>
        <translation>התגלתה שגיאת אמצעי אחסון. התקן האחסון פגום או שעבר חבלה. נא לנסות התקן אחר.</translation>
    </message>
    <message>
        <source>Invalid disk parameter. The storage device may not be properly recognized. Please try reconnecting the device.</source>
        <translation>משתנה שגוי לכונן. התקן האחסון כנראה לא מזוהה כראוי. נא לנסות לחבר אותו שוב.</translation>
    </message>
    <message>
        <source>I/O device error. The storage device may have been disconnected or is malfunctioning.</source>
        <translation>שגיאת התקן קלט/פלט. יכול להיות שהתקן האחסון נותק או שהוא פגום.</translation>
    </message>
    <message>
        <source>Error opening disk device &apos;%1&apos;</source>
        <translation>שגיאה בפתיחת התקן האחסון ‚%1’</translation>
    </message>
    <message>
        <source>Error getting device size</source>
        <translation>שגיאה בקבלת גודל ההתקן</translation>
    </message>
    <message>
        <source>Error writing to storage device. Please check if the device is writable, has sufficient space, and is not write-protected.</source>
        <translation>שגיאה בצריבה להתקן האחסון. נא לבדוק אם ההתקן זמין לכתיבה, האם יש בו מספיק מקום ושאין עליו הגנה מפני כתיבה.</translation>
    </message>
    <message>
        <source>Unmounting drive...</source>
        <translation>עיגון הכונן מנותק…</translation>
    </message>
    <message>
        <source>Opening drive...</source>
        <translation>הכונן נפתח…</translation>
    </message>
    <message>
        <source>Discarding existing data on drive...</source>
        <translation>הנתונים הקיימים בכונן מסולקים…</translation>
    </message>
    <message>
        <source>Zero&apos;ing out first and last MB of drive...</source>
        <translation>המגה בתים הראשון והאחרון בכונן מתמלאים באפסים…</translation>
    </message>
    <message>
        <source>Starting download...</source>
        <translation>ההורדה מתחילה…</translation>
    </message>
    <message>
        <source>Writing image...</source>
        <translation>הדמות נצרבת…</translation>
    </message>
    <message>
        <source>Customising OS...</source>
        <translation>מערכת ההפעלה עוברת התאמה…</translation>
    </message>
    <message>
        <source>Cannot open storage device &apos;%1&apos;. Please run with elevated privileges (sudo).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating signed boot image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to create secure boot files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No RSA key configured for secure boot. Please select a key in App Options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSA key file not found: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extracting boot partition files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to extract boot partition files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No boot files found to package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to create temporary directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating boot.img...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to create boot.img</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Signing boot image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to generate boot.sig</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to read boot.img</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to read boot.sig</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cleaning up boot partition...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncing deletions to disk...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing signed boot files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to write secure boot files: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unmounting volumes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cleaning disk...</source>
        <translation type="unfinished">הכונן מתנקה…</translation>
    </message>
    <message>
        <source>Cleaning disk (legacy method)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing customization files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to allocate buffer for MBR zeroing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DriveFormatThread</name>
    <message>
        <source>Error opening device for formatting</source>
        <translation>שגיאה בפתיחת ההתקן לפרמוט</translation>
    </message>
    <message>
        <source>Error writing to device during formatting</source>
        <translation>שגיאה בצריבה להתקן במהלך פרמוט</translation>
    </message>
    <message>
        <source>Error seeking on device during formatting</source>
        <translation>שגיאת חתירה בהתקן במהלך פרמוט</translation>
    </message>
    <message>
        <source>Invalid parameters for formatting</source>
        <translation>משתנים שגויים לפרמוט</translation>
    </message>
    <message>
        <source>Insufficient space on device</source>
        <translation>אין מספיק מקום בכונן</translation>
    </message>
    <message>
        <source>Unknown formatting error</source>
        <translation>שגיאת פרמוט לא ידועה</translation>
    </message>
    <message>
        <source>Preparing disk for formatting...</source>
        <translation>מתבצעת הכנת הכונן לפרמוט…</translation>
    </message>
    <message>
        <source>Cleaning disk...</source>
        <translation>הכונן מתנקה…</translation>
    </message>
    <message>
        <source>Writing filesystem...</source>
        <translation>מערכת הקבצים נצרבת…</translation>
    </message>
    <message>
        <source>Cannot format device: insufficient permissions. Please run with elevated privileges (sudo).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWListModel</name>
    <message>
        <source>CHOOSE DEVICE</source>
        <translation>נא לבחור מכשיר</translation>
    </message>
</context>
<context>
    <name>HostnameCustomizationStep</name>
    <message>
        <source>A hostname is a unique name that identifies your Raspberry Pi on the network. It should contain only letters, numbers, and hyphens.</source>
        <translation>שם מארח הוא שם ייחודי שעוזר לזהות את ה־Raspberry Pi שלך ברשת. הוא אמור להכיל תווים, ספרות ומינוסים בלבד.</translation>
    </message>
    <message>
        <source>Customisation: Choose hostname</source>
        <translation>התאמה אישית: בחירת שם מארח</translation>
    </message>
    <message>
        <source>Enter your hostname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save hostname and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IfAndFeaturesCustomizationStep</name>
    <message>
        <source>Enable hardware interfaces and connectivity options.</source>
        <translation>הפעלת ממשקי חומרה ואפשרויות קישוריות.</translation>
    </message>
    <message>
        <source>Interfaces</source>
        <translation>ממשקים</translation>
    </message>
    <message>
        <source>Enable SPI</source>
        <translation>הפעלת SPI</translation>
    </message>
    <message>
        <source>Enable Serial:</source>
        <translation>הפעלת חיבור טורי:</translation>
    </message>
    <message>
        <source>Features</source>
        <translation>יכולות</translation>
    </message>
    <message>
        <source>Enable USB Gadget Mode</source>
        <translation>הפעלת מצב חפיץ USB</translation>
    </message>
    <message>
        <source>Learn more about USB Gadget Mode</source>
        <translation>מידע נוסף על מצב חפיץ USB</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>מסוף</translation>
    </message>
    <message>
        <source>USB Gadget Mode can change how your device behaves and may impact connectivity and host interaction.</source>
        <translation>מצב חפיץ USB יכול לשנות את איך שההתקן שלך מתנהג ועלול להשפיע על חיבורים והתפעול מצד המארח.</translation>
    </message>
    <message>
        <source>Please review the &lt;a href=&apos;%1&apos;&gt;documentation&lt;/a&gt; before proceeding.</source>
        <translation>נא לפנות ל&lt;a href=&apos;%1&apos;&gt;תיעוד&lt;/a&gt; לפני המשך התהליך.</translation>
    </message>
    <message>
        <source>Only continue if you are sure you know what you are doing.</source>
        <translation>כדאי להמשיך רק אם ברור לך לחלוטין מה הן ההשלכות של המעשים שלך.</translation>
    </message>
    <message>
        <source>I understand, continue</source>
        <translation>ברור לי, אפשר להמשיך</translation>
    </message>
    <message>
        <source>Customisation: Interfaces &amp; Features</source>
        <translation>התאמה אישית: ממשקים ויכולות</translation>
    </message>
    <message>
        <source>Enable I2C</source>
        <translation>הפעלת I2C</translation>
    </message>
    <message>
        <source>Enable 1-Wire</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable the I2C (Inter-Integrated Circuit) interface for connecting sensors and other low-speed peripherals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable the SPI (Serial Peripheral Interface) for high-speed communication with displays and sensors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable the 1-Wire interface for connecting temperature sensors and other Dallas/Maxim devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable USB device mode to use your Raspberry Pi as a USB peripheral for networking and storage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save interface and feature settings and continue to writing step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the serial interface: Disabled, Default (system decides), Console &amp; Hardware (both console and UART), Hardware (UART only), or Console (console only on supported devices).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USB Gadget Mode Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please review the documentation before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel and return to the interfaces and features settings without enabling USB Gadget Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm that you understand the risks and continue with USB Gadget Mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This button will be enabled after 2 seconds</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImComboBox</name>
    <message>
        <source>Type to search: &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(press again to cycle)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImFileDialog</name>
    <message>
        <source>Select File</source>
        <translation>בחירת קובץ</translation>
    </message>
    <message>
        <source>Enter path or URL…</source>
        <translation>נא למלא נתיב או כתובת…</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>תיקיות</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>פתיחה</translation>
    </message>
    <message>
        <source>Removable drives</source>
        <translation>כוננים נתיקים</translation>
    </message>
    <message>
        <source>Go up a folder</source>
        <translation>עלייה תיקייה אחת למעלה</translation>
    </message>
    <message>
        <source>No files in this folder</source>
        <translation>אין קבצים בתיקייה הזאת</translation>
    </message>
    <message>
        <source>Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter filename…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Navigate to a folder using the panel on the left,
or type a path in the address bar above.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">שמירה</translation>
    </message>
</context>
<context>
    <name>ImOptionButton</name>
    <message>
        <source>Opens in browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImOptionPill</name>
    <message>
        <source>Opens in browser</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImPasswordField</name>
    <message>
        <source>Password is visible. Press F2 to hide.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is hidden. Press F2 to show.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is currently visible. Activate to hide it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is currently hidden. Activate to show it.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImPopup</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImSaveFileDialog</name>
    <message>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImTextField</name>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageWriter</name>
    <message>
        <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
        <translation>קובץ הקלט אינו דמות כונן תקנית.&lt;br&gt;גודל הקובץ על סך %1 בתים הוא לא מכפלה של 512 בתים.</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>נא לבחור דמות</translation>
    </message>
    <message>
        <source>STP is enabled on your Ethernet switch. Getting IP will take long time.</source>
        <translation>STP (פרוטוקול העץ הפורש) פעיל בציוד התקשורת שלך. קבלת כתובת IP תארוך זמן רב.</translation>
    </message>
    <message>
        <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1.</source>
        <translation>נפח האחסון לא גדול מספיק.&lt;br&gt;חייב להיות %1 לפחות.</translation>
    </message>
    <message>
        <source>B</source>
        <translation>ב׳</translation>
    </message>
    <message>
        <source>TB</source>
        <translation>ט״ב</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>ג״ב</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>מ״ב</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message>
        <source>%1.%2 %3</source>
        <translation>%1.%2 %3</translation>
    </message>
    <message>
        <source>Unknown precondition failure.</source>
        <translation>תנאי מוקדם לא ידוע נכשל.</translation>
    </message>
    <message>
        <source>Cannot start write. %1</source>
        <translation>לא ניתן להתחיל בצריבה. %1</translation>
    </message>
    <message>
        <source>Source file not found: %1</source>
        <translation>קובץ המקור לא נמצא: %1</translation>
    </message>
    <message>
        <source>Source is not a regular file: %1</source>
        <translation>המקור איננו קובץ רגיל: %1</translation>
    </message>
    <message>
        <source>Source file is not readable: %1</source>
        <translation>קובץ המקור אינו קריא: %1</translation>
    </message>
    <message>
        <source>image</source>
        <translation>דמות</translation>
    </message>
    <message>
        <source>storage device</source>
        <translation>התקן אחסון</translation>
    </message>
    <message>
        <source>valid storage device (device no longer available)</source>
        <translation>התקן אחסון תקף (ההתקן לא זמין עוד)</translation>
    </message>
    <message>
        <source>No %1 selected.</source>
        <translation>לא נבחר %1.</translation>
    </message>
    <message>
        <source> or </source>
        <translation> או </translation>
    </message>
    <message>
        <source>Save Performance Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JSON files (*.json);;All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeychainPermissionDialog</name>
    <message>
        <source>Keychain Access</source>
        <translation>גישה למחזיק מפתחות</translation>
    </message>
    <message>
        <source>Would you like to prefill the Wi‑Fi password from the system keychain?</source>
        <translation>למלא את סיסמת הרשת האלחוטית ממחזיק המפתחות של המערכת?</translation>
    </message>
    <message>
        <source>This will require administrator authentication on macOS.</source>
        <translation>הפעולה הזאת תדרוש אימות הנהלת מערכת ב־macOS.</translation>
    </message>
    <message>
        <source>Skip keychain access and manually enter the Wi-Fi password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieve the Wi-Fi password from the system keychain using administrator authentication</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageSelectionStep</name>
    <message>
        <source>Welcome</source>
        <translation>ברוך בואך</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>שפה:</translation>
    </message>
    <message>
        <source>Choose your language for Raspberry Pi Imager</source>
        <translation>נא לבחור את שפת צורב הדמויות ל־Raspberry Pi</translation>
    </message>
    <message>
        <source>Select the language for the Raspberry Pi Imager interface</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocalFileExtractThread</name>
    <message>
        <source>Error opening image file</source>
        <translation>שגיאה בפתיחת קובץ דמות</translation>
    </message>
    <message>
        <source>Error reading from image file</source>
        <translation>שגיאה בקריאה מקובץ דמות</translation>
    </message>
    <message>
        <source>Error writing to device</source>
        <translation>שגיאה בכתיבה להתקן</translation>
    </message>
    <message>
        <source>Failed to read complete image file</source>
        <translation>קריאת קובץ הדמות במלואו נכשלה</translation>
    </message>
    <message>
        <source>Opening image file...</source>
        <translation>קובץ הדמות נפתח…</translation>
    </message>
    <message>
        <source>Starting extraction...</source>
        <translation>החילוץ מתחיל…</translation>
    </message>
</context>
<context>
    <name>LocaleCustomizationStep</name>
    <message>
        <source>Keyboard layout:</source>
        <translation>פריסת מקלדת:</translation>
    </message>
    <message>
        <source>Time zone:</source>
        <translation>אזור זמן:</translation>
    </message>
    <message>
        <source>Customisation: Localisation</source>
        <translation>התאמה אישית: הגדרות שפה ואזור</translation>
    </message>
    <message>
        <source>Select your location for suggested time zone and keyboard layout</source>
        <translation>נא לבחור את אזור המחייה שלך לקבלת הצעות לאזור זמן ופריסת מקלדת</translation>
    </message>
    <message>
        <source>Capital city:</source>
        <translation>עיר הבירה:</translation>
    </message>
    <message>
        <source>Save localisation settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your nearest capital city. This will automatically recommend the correct time zone and keyboard layout for your region, and set the wireless regulatory domain for your country&apos;s Wi-Fi regulations.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your time zone so your Raspberry Pi displays the correct local time. This is automatically recommended based on your capital city selection, but you can change it if the suggestion is incorrect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your keyboard layout so keys produce the correct characters when typing. This is automatically recommended based on your capital city selection, but you can change it if you use a different keyboard layout.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacFile</name>
    <message>
        <source>Raspberry Pi Imager needs to access the disk to write the image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NativeFileDialog</name>
    <message>
        <source>File type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OSListModel</name>
    <message>
        <source>Recommended</source>
        <translation>מומלצת</translation>
    </message>
</context>
<context>
    <name>OSSelectionStep</name>
    <message>
        <source>Local - %1</source>
        <translation>מקומי - %1</translation>
    </message>
    <message>
        <source>Cached on your computer</source>
        <translation>שמור במטמון במחשב שלך</translation>
    </message>
    <message>
        <source>Local file</source>
        <translation>קובץ מקומי</translation>
    </message>
    <message>
        <source>Online - %1 download</source>
        <translation>מקוון - הורדה של %1</translation>
    </message>
    <message>
        <source>Go back to main menu</source>
        <translation>חזרה לתפריט הראשי</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>נא לבחור דמות</translation>
    </message>
    <message>
        <source>Choose operating system</source>
        <translation>בחירת מערכת הפעלה</translation>
    </message>
    <message>
        <source>Select an operating system to install on your Raspberry Pi</source>
        <translation>נא לבחור מערכת הפעלה להתקנה ל־Raspberry Pi שלך</translation>
    </message>
    <message>
        <source>Operating system list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No operating systems</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 operating system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 operating systems</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operating system category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select, Left arrow to go back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PiConnectCustomizationStep</name>
    <message>
        <source>Customisation: Raspberry Pi Connect</source>
        <translation>התאמה אישית: Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>Enable Raspberry Pi Connect</source>
        <translation>הפעלת Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>What is Raspberry Pi Connect?</source>
        <translation>מה זה Raspberry Pi Connect?</translation>
    </message>
    <message>
        <source>Open Raspberry Pi Connect</source>
        <translation>פתיחת Raspberry Pi Connect</translation>
    </message>
    <message>
        <source>Token received from browser</source>
        <translation>התקבל אסימון מהדפדפן</translation>
    </message>
    <message>
        <source>Open the Raspberry Pi Connect website in your browser to sign in and receive an authentication token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable secure remote access to your Raspberry Pi through the Raspberry Pi Connect cloud service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Raspberry Pi Connect settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter or paste the authentication token from Raspberry Pi Connect. The token will be automatically filled if you use the &apos;Open Raspberry Pi Connect&apos; button to sign in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for token (%1s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste token here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The token you entered is not valid. Please check the token and try again, or use the &apos;Open Raspberry Pi Connect&apos; button to get a valid token.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">אישור</translation>
    </message>
    <message>
        <source>Close this dialog and return to the token field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication token:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign in to receive a token and enable Raspberry Pi Connect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Raspberry Pi Imager requires elevated privileges to write to storage devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Without this, you will encounter permission errors when writing images.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are not running as Administrator.

Please run as Administrator.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are not running as root.

Please run with elevated privileges: sudo %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are not running as root.

Click &quot;Install Authorization&quot; to set up automatic privilege elevation, or run manually with: sudo %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemoteAccessStep</name>
    <message>
        <source>Enable SSH</source>
        <translation>הפעלת SSH</translation>
    </message>
    <message>
        <source>Use password authentication</source>
        <translation>להשתמש באימות עם סיסמה</translation>
    </message>
    <message>
        <source>Use public key authentication</source>
        <translation>להשתמש באימות עם מפתח ציבורי</translation>
    </message>
    <message>
        <source>Customisation: SSH authentication</source>
        <translation>התאמה אישית: אימות SSH</translation>
    </message>
    <message>
        <source>Learn about SSH</source>
        <translation>מידע על SSH</translation>
    </message>
    <message>
        <source>Configure SSH access</source>
        <translation>הגדרת גישת SSH</translation>
    </message>
    <message>
        <source>Authentication mechanism:</source>
        <translation>מנגנון אימות:</translation>
    </message>
    <message>
        <source>Enable secure shell access for remote command-line control of your Raspberry Pi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save SSH settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow SSH login using the username and password you configured in the previous step.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow SSH login using a cryptographic key pair instead of a password. More secure than password authentication.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose how you will authenticate when connecting to your Raspberry Pi via SSH. Password authentication uses the account credentials you configured. Public key authentication uses a cryptographic key pair and is more secure.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RepositoryDialog</name>
    <message>
        <source>Content Repository</source>
        <translation>מאגר תוכן</translation>
    </message>
    <message>
        <source>Repository source:</source>
        <translation>מקור מאגר:</translation>
    </message>
    <message>
        <source>Use custom file</source>
        <translation>להשתמש בקובץ מותאם אישית</translation>
    </message>
    <message>
        <source>Please select a custom repository json file</source>
        <translation>נא לבחור קובץ json למאגר מותאם אישית</translation>
    </message>
    <message>
        <source>Select Repository</source>
        <translation>בחירת מאגר</translation>
    </message>
    <message>
        <source>Apply &amp; Restart</source>
        <translation>החלה והפעלה מחדש</translation>
    </message>
    <message>
        <source>Select custom repository</source>
        <translation>בחירת מאגר מותאם אישית</translation>
    </message>
    <message>
        <source>Use custom URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a custom repository JSON file from your computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close the repository dialog without changing the content source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply the new content repository and restart the wizard from the beginning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the source for operating system images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the official Raspberry Pi operating system repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load operating system list from a JSON file on your computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download operating system list from a custom web address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SecureBootCustomizationStep</name>
    <message>
        <source>Customisation: Secure Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure secure boot image signing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save secure boot settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Secure Boot Signing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign the boot partition with your RSA key to enable secure boot verification on Raspberry Pi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn about Secure Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will create boot.img and boot.sig files required for Raspberry Pi Secure Boot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public Key Fingerprint: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(unavailable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(unable to compute)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RSA Private Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select RSA Private Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PEM Files (*.pem);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your boot partition will be signed using the selected RSA private key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select an RSA private key above to enable secure boot signing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PEM Files (*.pem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SshKeyManager</name>
    <message>
        <source>No SSH keys configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 SSH key configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 SSH keys configured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide the list of SSH keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the list of SSH keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH keys list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1: %2, %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH key %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove SSH key: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove SSH key %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste key or click BROWSE to select file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSH public key input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste an SSH public key here or use the browse button to select a key file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select SSH Public Key</source>
        <translation type="unfinished">בחירת מפתח SSH ציבורי</translation>
    </message>
    <message>
        <source>Add the entered SSH key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an SSH public key file to add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StorageSelectionStep</name>
    <message>
        <source>No storage devices found</source>
        <translation>לא נמצאו התקני אחסון</translation>
    </message>
    <message>
        <source>Mounted as %1</source>
        <translation>מעוגן בתור %1</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>לקריאה בלבד</translation>
    </message>
    <message>
        <source>Select your storage device</source>
        <translation>נא לבחור את התקן האחסון שלך</translation>
    </message>
    <message>
        <source>Exclude system drives</source>
        <translation>החרגת כונני מערכת</translation>
    </message>
    <message>
        <source>Storage device list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to navigate, Enter or Space to select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All visible devices are read-only.
Try connecting a new device, or uncheck
&apos;Exclude system drives&apos; below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All devices are read-only.
Please connect a writable storage device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All devices are hidden by the filter.
Uncheck &apos;Exclude system drives&apos; below
to show system drives.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When checked, system drives are hidden from the list. Uncheck to show all drives including system drives.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No storage devices found. Please connect a storage device to continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. All visible devices are read-only. Try connecting a new storage device, or uncheck &apos;Exclude system drives&apos; to show hidden system drives.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. All devices are read-only. Please connect a writable storage device to continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid storage devices are currently available. Uncheck &apos;Exclude system drives&apos; to show hidden system drives, or connect a new storage device.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateAvailableDialog</name>
    <message>
        <source>Update available</source>
        <translation>יש עדכון</translation>
    </message>
    <message>
        <source>There is a newer version of Imager available. Would you like to visit the website to download it?</source>
        <translation>יש גרסה חדשה יותר של צורב הדמויות. לבקר באתר כדי להוריד אותה?</translation>
    </message>
    <message>
        <source>Continue using the current version of Raspberry Pi Imager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the Raspberry Pi website in your browser to download the latest version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserCustomizationStep</name>
    <message>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>נא למלא סיסמה</translation>
    </message>
    <message>
        <source>Confirm password:</source>
        <translation>אישור הסיסמה:</translation>
    </message>
    <message>
        <source>Re-enter password</source>
        <translation>נא למלא את הסיסמה שוב</translation>
    </message>
    <message>
        <source>The username must be lowercase and contain only letters, numbers, underscores, and hyphens.</source>
        <translation>שם המשתמש חייב להיות באותיות קטנות ולהכיל רק תווים, ספרות, קווים תחתיים ומינוסים.</translation>
    </message>
    <message>
        <source>Customisation: Choose username</source>
        <translation>התאמה אישית: בחירת שם משתמש</translation>
    </message>
    <message>
        <source>Saved (hidden) — leave blank to keep</source>
        <translation>שמור (מוסתר) - יש לרוקן כדי להשאיר</translation>
    </message>
    <message>
        <source>Re-enter to change password</source>
        <translation>נא למלא מחדש כדי לשנות את הסיסמה שלך</translation>
    </message>
    <message>
        <source>Create a user account for your Raspberry Pi</source>
        <translation>יצירת חשבון משתמש ל־Raspberry Pi שלך</translation>
    </message>
    <message>
        <source>Enter your username</source>
        <translation>נא למלא את שם המשתמש שלך</translation>
    </message>
    <message>
        <source>Save user account settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a username for your Raspberry Pi account. The username must be lowercase and contain only letters, numbers, underscores, and hyphens.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a new password for this account, or leave blank to keep the previously saved password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a password for this account. You will need to re-enter it in the next field to confirm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-enter the new password to confirm, or leave blank to keep the previously saved password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-enter the password to confirm it matches.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WifiCustomizationStep</name>
    <message>
        <source>SSID:</source>
        <translation>שם רשת (SSID):</translation>
    </message>
    <message>
        <source>Network name</source>
        <translation>שם הרשת</translation>
    </message>
    <message>
        <source>Network password</source>
        <translation>סיסמת הרשת</translation>
    </message>
    <message>
        <source>Hidden SSID</source>
        <translation>רשת מוסתרת (BSSID)</translation>
    </message>
    <message>
        <source>Customisation: Choose Wi‑Fi</source>
        <translation>התאמה אישית: בחירת רשת אלחוטית</translation>
    </message>
    <message>
        <source>No password (open network)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved (hidden) — leave blank to keep</source>
        <translation type="unfinished">שמור (מוסתר) - יש לרוקן כדי להשאיר</translation>
    </message>
    <message>
        <source>Secure network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Wi-Fi for a password-protected network with WPA2/WPA3 encryption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Wi-Fi for an unencrypted network without password protection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is too short (min 8 characters)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password is too long (max 63 characters)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password contains unsupported characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm password:</source>
        <translation type="unfinished">אישור הסיסמה:</translation>
    </message>
    <message>
        <source>Re-enter password</source>
        <translation type="unfinished">נא למלא את הסיסמה שוב</translation>
    </message>
    <message>
        <source>Save Wi-Fi settings and continue to next customisation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip all customisation and proceed directly to writing the image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the network name (SSID) of your Wi-Fi network. This is the name that appears when you search for available networks.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a new Wi-Fi password, or leave blank to keep the previously saved password. Must be 8-63 characters or a 64-character hexadecimal key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter your Wi-Fi network password. Must be 8-63 characters or a 64-character hexadecimal key. You will need to re-enter it in the next field to confirm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-enter the new Wi-Fi password to confirm, or leave blank to keep the previously saved password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-enter the Wi-Fi password to confirm it matches.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this if your Wi-Fi network does not broadcast its name and requires manual SSID entry to connect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re-enter to change password</source>
        <translation type="unfinished">נא למלא מחדש כדי לשנות את הסיסמה שלך</translation>
    </message>
</context>
<context>
    <name>WizardContainer</name>
    <message>
        <source>Device</source>
        <translation>התקן</translation>
    </message>
    <message>
        <source>OS</source>
        <translation>מערכת הפעלה</translation>
    </message>
    <message>
        <source>Storage</source>
        <translation>אחסון</translation>
    </message>
    <message>
        <source>Writing</source>
        <translation>צריבה</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>הסתיימה</translation>
    </message>
    <message>
        <source>Customisation</source>
        <translation>התאמה אישית</translation>
    </message>
    <message>
        <source>Hostname</source>
        <translation>שם מארח</translation>
    </message>
    <message>
        <source>User</source>
        <translation>משתמש</translation>
    </message>
    <message>
        <source>Wi‑Fi</source>
        <translation>רשת אלחוטית</translation>
    </message>
    <message>
        <source>Raspberry Pi Connect</source>
        <translation></translation>
    </message>
    <message>
        <source>App Options</source>
        <translation>אפשרויות היישום</translation>
    </message>
    <message>
        <source>Interfaces &amp; Features</source>
        <translation>ממשק ויכולות</translation>
    </message>
    <message>
        <source>Setup steps</source>
        <translation>שלבי הגדרה</translation>
    </message>
    <message>
        <source>Localisation</source>
        <translation>הגדרות שפה ואזור</translation>
    </message>
    <message>
        <source>Remote access</source>
        <translation>גישה מרחוק</translation>
    </message>
    <message>
        <source>Open application settings to configure sound alerts, auto-eject, telemetry, and content repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace existing Raspberry Pi Connect token?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new Raspberry Pi Connect token was received that differs from your current one.

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing token?

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace the current token with the newly received one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep existing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep your current Raspberry Pi Connect token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Secure Boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: Only overwrite the token if you initiated this action.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WizardStepBase</name>
    <message>
        <source>Next</source>
        <translation>הבא</translation>
    </message>
    <message>
        <source>Skip customisation</source>
        <translation>דילוג על התאמה אישית</translation>
    </message>
</context>
<context>
    <name>WritingStep</name>
    <message>
        <source>Review your choices and write the image to the storage device</source>
        <translation>מעבר שוב על הבחירות שלך וצריבת הדמות להתקן האחסון</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>צריבה</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>סיכום</translation>
    </message>
    <message>
        <source>Starting write process...</source>
        <translation>תהליך הצריבה מתחיל…</translation>
    </message>
    <message>
        <source>You are about to ERASE all data on: %1</source>
        <translation>הפעולה הזאת תמחק את כל הנתונים שעל: %1</translation>
    </message>
    <message>
        <source>the storage device</source>
        <translation>התקן האחסון</translation>
    </message>
    <message>
        <source>This action is PERMANENT and CANNOT be undone.</source>
        <translation>הפעולה הזאת היא לצמיתות והיא בלתי הפיכה.</translation>
    </message>
    <message>
        <source>I understand, erase and write</source>
        <translation>ברור לי, אפשר למחוק ולצרוב</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>נא להמתין…</translation>
    </message>
    <message>
        <source>Writing... %1%</source>
        <translation>מתבצעת צריבה… %1%</translation>
    </message>
    <message>
        <source>Verifying... %1%</source>
        <translation>מתבצע אימות… %1%</translation>
    </message>
    <message>
        <source>Write completed successfully!</source>
        <translation>הצריבה הושלמה בהצלחה!</translation>
    </message>
    <message>
        <source>Write failed: %1</source>
        <translation>הצריבה נכשלה: %1</translation>
    </message>
    <message>
        <source>Customisations to apply:</source>
        <translation>התאמות אישיות להחלה:</translation>
    </message>
    <message>
        <source>Finalising...</source>
        <translation>התהליך מסתיים…</translation>
    </message>
    <message>
        <source>Write image</source>
        <translation>צריבת דמות</translation>
    </message>
    <message>
        <source>Operating system:</source>
        <translation>מערכת הפעלה:</translation>
    </message>
    <message>
        <source>Cancel and return to the write summary without erasing the storage device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm erasure and begin writing the image to the storage device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel write</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip verification and finish the write process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel the write operation and return to the summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue to the completion screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Begin writing the image to the storage device. All existing data will be erased.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to previous customization step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finalising…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>customization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>customizations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing in progress — do not disconnect the storage device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait... %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Are you sure you want to quit?</source>
        <translation>לצאת?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <source>Format card as FAT32</source>
        <translation>פרמוט הכרטיס כ־FAT32</translation>
    </message>
    <message>
        <source>Use custom</source>
        <translation>להשתמש בהתאמה אישית</translation>
    </message>
    <message>
        <source>Select a custom .img from your computer</source>
        <translation>בחירת קובץ ‎.img מותאם מהמחשב שלך</translation>
    </message>
    <message>
        <source>Raspberry Pi Imager is still busy. Are you sure you want to quit?</source>
        <translation>צורב הדמויות ל־Raspberry Pi עדיין עסוק. לצאת?</translation>
    </message>
    <message>
        <source>Storage device removed</source>
        <translation>התקן האחסון הוסר</translation>
    </message>
    <message>
        <source>The storage device was removed while writing, so the operation was cancelled. Please reinsert the device or select a different one to continue.</source>
        <translation>התקן האחסון הוסר תוך כדי כתיבה, לכן הפעולה בוטלה. נא להכניס את ההתקן או לבחור בהתקן אחר כדי להמשיך.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
    <message>
        <source>Close the error dialog and continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close the storage removed notification and return to storage selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return to Raspberry Pi Imager and continue the current operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force quit Raspberry Pi Imager and cancel the current write operation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raspberry Pi Imager %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insufficient Permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error message explaining why elevated privileges are required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Raspberry Pi Imager - you must restart with elevated privileges to write images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install Authorization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Install system authorization to allow Raspberry Pi Imager to run with elevated privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Performance Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JSON files (*.json)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished">כל הקבצים (*)</translation>
    </message>
</context>
</TS>
